@@ -41,7 +41,7 @@
 #include <memory>
 
 // Local
-#include "Debug.h"
+#include "DebugResources.h"
 #include "Utils.h"
 
 #include <common/database/Database.h>
@@ -53,59 +53,32 @@ public:
 
 };
 
-Common::Database &resourcesDatabase()
+Common::Database::Ptr resourcesDatabase()
 {
     static ResourcesDatabaseMigrator instance;
-    return *(instance.d->database);
-}
-
-void ResourcesDatabaseMigrator::migrateDatabase(const QString &newDatabaseFile) const
-{
-    // Checking whether we need to transfer the KActivities/KDE4
-    // sqlite database file to the new location.
-    if (QFile(newDatabaseFile).exists()) {
-        return;
-    }
-
-    // Testing for kdehome
-    Kdelibs4Migration migration;
-    if (!migration.kdeHomeFound()) {
-        return;
-    }
-
-    QString oldDatabaseFile(
-        migration.locateLocal("data", "activitymanager/resources/database"));
-    if (!oldDatabaseFile.isEmpty()) {
-        QFile(oldDatabaseFile).copy(newDatabaseFile);
-    }
+    return instance.d->database;
 }
 
 ResourcesDatabaseMigrator::ResourcesDatabaseMigrator()
-    : d()
 {
     const QString databaseDir
         = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
           + QStringLiteral("/kactivitymanagerd/resources/");
 
-    qDebug() << "Creating directory: " << databaseDir;
+    qCDebug(KAMD_LOG_RESOURCES) << "Creating directory: " << databaseDir;
     auto created = QDir().mkpath(databaseDir);
 
     if (!created || !QDir(databaseDir).exists()) {
-        qWarning() << "Database folder can not be created!";
+        qCWarning(KAMD_LOG_RESOURCES) << "Database folder can not be created!";
     }
 
-    const QString newDatabaseFile = databaseDir + QStringLiteral("database");
-
-    migrateDatabase(newDatabaseFile);
-
     d->database = Common::Database::instance(
             Common::Database::ResourcesDatabase,
             Common::Database::ReadWrite);
 
-    Q_ASSERT_X(d->database, "SQLite plugin/Database constructor",
-                            "Database could not be opened");
-
-    Common::ResourcesDatabaseSchema::initSchema(*d->database);
+    if (d->database) {
+        Common::ResourcesDatabaseSchema::initSchema(*d->database);
+    }
 }
 
 ResourcesDatabaseMigrator::~ResourcesDatabaseMigrator()
